@@ -806,6 +806,18 @@ class SearchQuery(BaseSearchQuery):
         super(SearchQuery, self).__init__(backend=backend)
         self.backend = backend or SearchBackend()
     
+    def run(self, spelling_query=None):
+        try:
+            return super(SearchQuery, self).run(spelling_query=spelling_query)
+        except xapian.DatabaseModifiedError:
+            return super(SearchQuery, self).run(spelling_query=spelling_query)
+
+    def run_mlt(self):
+        try:
+            return super(SearchQuery, self).run_mlt()
+        except xapian.DatabaseModifiedError:
+            return super(SearchQuery, self).run_mlt()
+    
     def build_query(self):
         if not self.query_filter:
             query = xapian.Query('')
@@ -834,8 +846,8 @@ class SearchQuery(BaseSearchQuery):
                 ) for term, value in self.boost.iteritems()
             ]
             query = xapian.Query(
-                xapian.Query.OP_OR, query,
-                xapian.Query(xapian.Query.OP_AND, subqueries)
+                xapian.Query.OP_AND_MAYBE, query,
+                xapian.Query(xapian.Query.OP_OR, subqueries)
             )
         
         return query
